@@ -3,4 +3,6 @@ from .mlmodel import MLModel
 from .request import Request
 from .execution import Execution
 from .dsapi_json_encoder import DSAPIEncoder
+from .dataframe_toolkit import DataFrameToolkit
+from .model_toolkit import ModelToolkit
 from .wizata_dsapi_client import WizataDSAPIClient
\ No newline at end of file
